@@ -26,6 +26,8 @@ class MerchantConfiguration:
         self.authentication_type = None
         self.key_file_path = None
         self.run_environment = None
+        self.IntermediateHost = None
+        self.default_headers = None
         self.key_alias = None
         self.key_password = None
         self.enable_client_cert = None
@@ -86,6 +88,14 @@ class MerchantConfiguration:
         if not (value.get('portfolio_id') is None):
             self.portfolio_id = value['portfolio_id']
 
+    def set_IntermediateHost(self, value):
+        if not (value.get('IntermediateHost') is None):
+            self.IntermediateHost = value['IntermediateHost']
+
+    def set_default_headers(self, value):
+        if not (value.get('default_headers') is None):
+            self.default_headers = value['default_headers']
+
     def set_run_environment(self, value):
         if not (value.get('run_environment') is None):
             self.run_environment = value['run_environment']
@@ -170,6 +180,8 @@ class MerchantConfiguration:
         self.set_use_metakey(val)
         self.set_portfolio_id(val)
         self.set_run_environment(val)
+        self.set_IntermediateHost(val)
+        self.set_default_headers(val)
         self.set_merchant_id(val)
         self.set_authentication_type(val)
         self.set_request_host(val)
